==> haskell-svg-builder-0.1.1-189-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-svg-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 svg-builder
version:              0.1.1
visibility:           public
id:                   svg-builder-0.1.1-GTbH4JS84KlLkpUtxJAA65
key:                  svg-builder-0.1.1-GTbH4JS84KlLkpUtxJAA65
license:              BSD-3-Clause
copyright:            2016 Jeffrey Rosenbluth
maintainer:           jeffrey.rosenbluth@gmail.com
author:               Jeffrey Rosenbluth
homepage:             https://github.com/diagrams/svg-builder.git
synopsis:             DSL for building SVG.
description:          Fast, easy to write SVG.
category:             Graphics
abi:                  8d95dc751899f875522ae17ccd387de7
exposed:              True
exposed-modules:
    Graphics.Svg Graphics.Svg.Attributes Graphics.Svg.Core
    Graphics.Svg.Elements Graphics.Svg.Path

import-dirs:          /usr/lib/ghc-9.2.8/site-local/svg-builder-0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/svg-builder-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-svg-builder
hs-libraries:         HSsvg-builder-0.1.1-GTbH4JS84KlLkpUtxJAA65
depends:
    base-4.16.4.0 blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    bytestring-0.11.4.0 hashable-1.4.4.0-1DKi0WUbpLrE22bUerprT9
    text-1.2.5.0 unordered-containers-0.2.20-EKpOBluUqpuDOTuVUTImll

haddock-interfaces:   /usr/share/doc/haskell-svg-builder/html/svg-builder.haddock
haddock-html:         /usr/share/doc/haskell-svg-builder/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-svg-builder-0.1.1-190-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-svg-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 svg-builder
version:              0.1.1
visibility:           public
id:                   svg-builder-0.1.1-49Ln3SAb9LzBjbZdvhdgCi
key:                  svg-builder-0.1.1-49Ln3SAb9LzBjbZdvhdgCi
license:              BSD-3-Clause
copyright:            2016 Jeffrey Rosenbluth
maintainer:           jeffrey.rosenbluth@gmail.com
author:               Jeffrey Rosenbluth
homepage:             https://github.com/diagrams/svg-builder.git
synopsis:             DSL for building SVG.
description:          Fast, easy to write SVG.
category:             Graphics
abi:                  d57b838ec26d0b84cfb75ed3e31d45cd
exposed:              True
exposed-modules:
    Graphics.Svg Graphics.Svg.Attributes Graphics.Svg.Core
    Graphics.Svg.Elements Graphics.Svg.Path

import-dirs:          /usr/lib/ghc-9.2.8/site-local/svg-builder-0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/svg-builder-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-svg-builder
hs-libraries:         HSsvg-builder-0.1.1-49Ln3SAb9LzBjbZdvhdgCi
depends:
    base-4.16.4.0 blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    bytestring-0.11.4.0 hashable-1.4.4.0-LbPl9rwTnDUL4mxyCHHqh0
    text-1.2.5.0 unordered-containers-0.2.20-4Y4A6Wn35BzvWquDAxs4Y

haddock-interfaces:   /usr/share/doc/haskell-svg-builder/html/svg-builder.haddock
haddock-html:         /usr/share/doc/haskell-svg-builder/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
